#
# spec file for package python-pifpaf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pifpaf
Version:        2.1.2
Release:        3.20
Summary:        Suite of tools and fixtures to manage daemons for testing
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/jd/pifpaf
Source:         https://pypi.io/packages/source/p/pifpaf/pifpaf-%{version}.tar.gz
BuildRequires:  %{python_module pbr}
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-click
Requires:       python-daiquiri
Requires:       python-fixtures
Requires:       python-mock
Requires:       python-psutil
Requires:       python-requests
Requires:       python-six
Requires:       python-testrepository
Requires:       python-testtools
Requires:       python-xattr
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%python_subpackages

%description
Pifpaf is a suite of `fixtures`_ and a command-line tool that allows to start
and stop daemons for a quick throw-away usage. This is typically useful when
needing these daemons to run `integration testing`_. It originaly evolved from
its precussor `overtest`_.

%prep
%setup -q -n pifpaf-%{version}

%build
export LC_ALL=en_US.utf8
%python_build

%install
export LC_ALL=en_US.utf8
%python_install
%python_clone -a %{buildroot}%{_bindir}/pifpaf

%post
%python_install_alternative pifpaf

%postun
%python_uninstall_alternative pifpaf

%files %{python_files}
%license LICENSE
%doc ChangeLog README.rst
%{python_sitelib}/*
%python_alternative %{_bindir}/pifpaf

%changelog
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Nov 28 2018 dmueller@suse.com
- update to 2.1.2:
  * Setup 2 partitions per topic
  * pep8: enable flake8-logging-format
  * fix py3 flake8 error
  * gnocchi: Don't install outdated version
  * tests: Remove s3srv testing
  * ceph: Allow to delete pool
  * Add .mergify.yml
* Tue Sep  4 2018 dmueller@suse.com
- update to 2.1.1
  * ceph: allow to run luminuous
  * various small bugfixes
* Fri Feb 23 2018 tbechtold@suse.com
- update to 2.0.5:
  * Fix s3rver for latest version
  * Revert "wait the pifpaf process termination in fork mode"
  * Use last ceph lts
  * gnocchi: use gnocchi-api binary when possible
  * wait the pifpaf process termination in fork mode
  * Fix exception handling
  * swift: use all needed workers
  * Fix exit code not being propagated
* Wed Jan 17 2018 tbechtold@suse.com
- update to 2.0.0:
  * Replace cliff by click
  * Set the Cliff namespace
  * Wait logging thread and close the fd
  * Use psutil to cleanup process
  * Fix travis CI
  * swift: use 127.0.0.1 instead of localhost for memcached
  * gnocchi: run 4 api processes
  * Remove deprecated parameters from server.properties
  * gnocchi: allow any workers as possible
  * Replace hacking with flake8 extensions
  * Update wait\_for\_line for Kafka 1.0.0 server
  * Update config for 0.11 kafka server
  * Add leseb image in README.rst
  * gnocchi: handle virtual env on API
  * correct disk name
  * create data directory for swift
  * Push release to PyPI using Travis
  * Fix Python 2 ProcessLookupError
  * Handle terminate lookup error
  * tests: call setUp to init cleanups
  * postgresql: do not call \_exec in \_\_init\_\_
  * Install mock for tests
  * Remove not used oslotest dependency
  * Fix process cleanup
  * Ensure pifpaf kill all processes
  * Fix compatibility with Redis 4.0
* Fri Jul 28 2017 tbechtold@suse.com
- convert to singlespec
* Fri Jul 28 2017 tbechtold@suse.com
- update to 1.9.2:
  * Revert "Ensure pifpaf kill all processes"
  * Ensure pifpaf kill all processes
  * Add a new driver for Vault
  * Fix logging in \_kill
  * memcached: don't read stdout
  * swift: fix configuration typo
  * swiftclient default auth to 2.0
  * swift: start a dedicated memcached
  * Disable elastic search tests
  * Ensure xattr are available for swift
  * swift: check we can upload file
  * Use subprocess to kill process
  * Fix decorator order
  * Simplify retry logic
  * Fix retry error catching
  * Wait 10 seconds processes to end, them kill them
  * Revert "gnocchi: use --reuse-port"
  * gnocchi: use --reuse-port
  * Do not use concurrency to run tests
  * Fix conflicting port in Gnocchi test
  * Use another port for test\_gnocchi\_with\_redis\_coordinator
  * Fix pep8 error
  * Revert "gnocchi: remove deprecated uwsgi option die-on-term"
  * gnocchi: ensure client don't use keepalive
  * gnocchi: add --no-orphans to uwsgi
  * gnocchi: remove deprecated uwsgi option die-on-term
  * gnocchi: only run 1 metricd
  * gnocchi: add missing backslash in re
  * gnocchi: chdir to tempdir in uwsgi
  * Fix uwsgi wait for line
  * Revert "Make uwsgi loading module within a virtualenv"
  * gnocchi: remove --plugin options
  * Make uwsgi loading module within a virtualenv
  * Remove Python 3.4 support
  * Switch to uwsgi to run gnocchi-api
  * elasticsearch: fix new versions option passing
  * Add npm to Travis install
  * Fix logging being done on stdout instead of stderr
  * Stop using stevedore to load plugins
  * gnocchi: set verbose in config file to be sure info are printed
  * Revert "gnocchi: pass --verbose to daemon to be sure they're in INFO mode"
  * gnocchi: pass --verbose to daemon to be sure they're in INFO mode
  * Use daiquiri to setup logging
  * Fix error reporting in Python 3
  * Move Ceph requirements to an extra entry
  * Don't install xattr on win32 systems
  * Revert "aodh: use database-url for gnocchi indexer"
  * Set the actual dist for Travis
  * aodh: use database-url for gnocchi indexer
  * aodh: add database-url
  * fix DEFAULT\_PORT\_COORDINATOR variable name
  * gnocchi: allow to use redis coordinator
  * gnocchi: remove legacy resource types support
  * etcd: fix http url
  * gnocchi: enable debug mode when --debug is passed to pifpaf
  * Pass debug option to drivers
  * gnocchi: allow to use redis as storage
  * gnocchi: switch to basic auth as noauth is deprecated
  * fix s3/swift with username/password are None
  * Add link to Swift in README
  * gnocchi: unquote credentials for s3 backend
  * Allow Swift as Gnocchi storage backend
  * Add swift driver
  * Fix tox-travis deprecated warning
  * fix npm in travis
* Mon Feb 13 2017 tbechtold@suse.com
  update to version 0.24.1
  * doc: rabbitmq cluster is supported
  * tests: allow to find zookeeper bins
  * Make travis-ci happy again
  * ceph: increase rados object name limit for ext4 fs
  * gnocchi: start statsd daemon
  * gnocchi: Set statd old vars
  * tests: Fix a python3 bug
  * rabbit: put password for all hosts in the url
  * Set storage engine to mmapv1 when wiredtiger is not present
  * correctly decode application stdout
  * Revert "gnocchi: set auth_mode = noauth"
  * Add MongoDB to README
  * tests: Don't run them in //
  * gnocchi: allow to run with an existing storage URL
  * aodh: auth with basic against Gnocchi
  * Revert "mysql: fix timezone"
  * travis: fix mysql install
  * travis: remove tarball from cache
  * ceph: last jewel point release have lowered object max len
  * Clean variables on exit
  * gnocchi: fix statds waiting line for gnocchi <3.0
  * Revert "Partial revert for debug output"
  * mysql: fix timezone
  * gnocchi: set auth_mode = noauth
  * tests: fix env variable parsing
  * rabbit: use process group
  * Set a proper PS1 when invoked via eval
  * Gnocchi >= 3.1 will not ship any config by default
  * rabbitmq: fix waiting line
  * gnocchi: Add support to s3 backend
  * ceph: use shm and try to not really write data
  * Update influxdb.py
  * gnocchi: Reduce the metricd delays
  * gnocchi: allow to run with an existing indexer URL
  * tests: Capture logging and print it on failure
  * ceph: don't use /dev/shm
  * Bump hacking to 0.12
  * Implements the Kafka driver
  * Fix mysql gate
  * Fix a typo in README: gobal -> global
  * Add support for Python 3.6
  * cli: fully segment all environ vars
  * aodh: fix authentication disabling with newer Aodh
  * tests: fix s3rver tests
  * gnocchi: stop setting old statsd conf var
* Wed Aug 31 2016 tbechtold@suse.com
- update to 0.12.0:
  * Add support for s3rver
  * fakes3: export HTTP url
  * Mention CouchDB support in README
  * Add support for CouchDB
  * gnocchi: Catch a working line for metricd
  * Fix virtualenv handling
  * Revert "mysql: add --basedir=/usr"
  * mysql: fix typo
  * tests: fix mysqld database name
  * mysql: use pifpaf as the name of the database
  * mysql: add --basedir=/usr
  * mysql: use mysql_install_db if mysqld --initialize-insecure fails
  * mysql: add --no-defaults and --tmpdir to mysqld
  * Indicate we support etcd clustering
  * Support etcdctl
  * etcd: add clustering support
  * etcd: change default port to IANA and allow to change peer port
  * Print PID of process when logging output
  * Support for Aodh 3
  * Better reporting on wait_for_line
  * Print actual output when we don't find the expected line
  * tests: fix a port collision
  * tests: fix Popen usage with Python 3
  * Fix Python 3
  * Fix pep8 errors
  * influxdb: fix wait_for_line with re
  * ceph: fix output matching with re
  * Gnocchi: bugfix on wait_for_line on API
  * gnocchi: fix URL in waiting
  * keystone: disable tests
  * zookeeper: wait for ZooKeeper to start before returning
  * Fix Redis driver with Redis 3.2.1
  * drivers: support regexp for wait_for_line
  * gnocchi: support latest master/2.2 changes on gnocchi-api
  * aodh: run aodh-evaluator
  * Install software via tox
  * keystone: simplify wait for line for admin
  * drivers: translate OSError to a more readable error
  * keystone: simplify wait_for_line
  * keystone: fix pep8 error in test
  * Add a Keystone driver
  * Better debugging on errors
  * Add a pifpaf_stop function to stop pifpaf
  * Fix typo in InfluxDB driver
  * influxdb: fix Python >= 3.0 & < 3.5
  * travis: Remove missing etcd from install
  * travis: install InfluxDB with wget
  * Add PyPI version badge
  * postgresql: allow to configure host, set to none by default
  * aodh: set AODH_ENDPOINT for aodh client
  * gnocchi: fix a regression on variable names
- Adjust Requires
- Use pypi.io as Source url
* Fri May 13 2016 tbechtold@suse.com
- Initial packaging (version 0.2.0)
